@@ -1,6 +1,6 @@
 package TPath::Predicate::AttributeTest;
 {
-  $TPath::Predicate::AttributeTest::VERSION = '0.003';
+  $TPath::Predicate::AttributeTest::VERSION = '0.004';
 }
 
 # ABSTRACT: implements the C<[@foo = 1]> in C<//a/b[@foo = 1]>
@@ -16,8 +16,8 @@ with 'TPath::Predicate';
 has at => ( is => 'ro', isa => 'TPath::AttributeTest', required => 1 );
 
 sub filter {
-    my ( $self, $c, $i ) = @_;
-    return grep { $self->at->test($_, $c, $i) } @$c;
+    my ( $self, $i, $c ) = @_;
+    return grep { $self->at->test($_, $i, $c) } @$c;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -34,7 +34,7 @@ TPath::Predicate::AttributeTest - implements the C<[@foo = 1]> in C<//a/b[@foo =
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
