@@ -1,6 +1,6 @@
 package TPath::Predicate::Expression;
 {
-  $TPath::Predicate::Expression::VERSION = '0.003';
+  $TPath::Predicate::Expression::VERSION = '0.004';
 }
 
 # ABSTRACT: implements the C<[c]> in C<//a/b[c]>
@@ -16,8 +16,8 @@ with 'TPath::Predicate';
 has e => ( is => 'ro', isa => 'TPath::Expression', required => 1 );
 
 sub filter {
-    my ( $self, $c, $i ) = @_;
-    return grep { $self->e->test( $_, $c, $i ) } @$c;
+    my ( $self, $i, $c ) = @_;
+    return grep { $self->e->test( $_, $i, $c ) } @$c;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -34,7 +34,7 @@ TPath::Predicate::Expression - implements the C<[c]> in C<//a/b[c]>
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
