@@ -1,6 +1,6 @@
 package TPath::Predicate::Index;
 {
-  $TPath::Predicate::Index::VERSION = '0.003';
+  $TPath::Predicate::Index::VERSION = '0.004';
 }
 
 # ABSTRACT: implements the C<[0]> in C<//a/b[0]>
@@ -15,7 +15,7 @@ with 'TPath::Predicate';
 has idx => ( is => 'ro', isa => 'Int', required => 1 );
 
 sub filter {
-    my ( $self, $c ) = @_;
+    my ( $self, undef, $c ) = @_;
     return $c->[ $self->idx ];
 }
 
@@ -33,7 +33,7 @@ TPath::Predicate::Index - implements the C<[0]> in C<//a/b[0]>
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
